import { NsImage } from '../';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel1Props = {
    cardTitle: string;
    cardDescription: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        '.content': {
            width: '50%',
            height: '100%',
            padding: '50px',
            paddingLeft: '100px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.image': {
            width: 'auto',
            height: '100%',
            display: 'block',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '20px',
        },
        '.body-text': {
            fontSize: '18px',
            marginBottom: '20px',
        },
        '.action-link': {
            marginTop: '10px',
        },
        '@media (max-width: 768px)': {
            display: 'block',
            height: 'auto',
            backgroundColor: '#edece9',
            '.content': {
                position: 'static',
                width: '100%',
                padding: '20px',
            },
        },
    };
});

const NsHeroCardLevel1 = ({
    cardTitle,
    cardDescription,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
}: NsHeroCardLevel1Props) => {
    return (
        <CardContainer className={className} data-testid="hero-card-level-1">
            <div className="image">
                <NsImage height={'auto'} width={'100%'} alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel1;
